==> nextcloud-25.0.12p1.tgz: nextcloud/apps/logreader/l10n/fa.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "ورود به سیستم",
    "Log Reader" : "ورود به سیستم خواننده",
    "A log reader for Nextcloud" : "خواننده گزارش برای Nextcloud",
    "Log reader for Nextcloud" : "خواننده را برای Nextcloud وارد کنید",
    "Log reader" : "Log reader",
    "Open log reader settings" : "Open log reader settings",
    "Log reader settings" : "Log reader settings",
    "Currently the log file {file} is shown" : "Currently the log file {file} is shown",
    "Show server log" : "Show server log",
    "Live view is disabled" : "Live view is disabled",
    "No log file" : "No log file",
    "File-based logging must be enabled to access logs from the Web UI." : "File-based logging must be enabled to access logs from the Web UI.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual.",
    "Level" : "ترک",
    "App" : "برنامه",
    "No app in context" : "No app in context",
    "Time" : "زمان",
    "Copy raw entry" : "Copy raw entry",
    "Copy formatted entry" : "Copy formatted entry",
    "Hide exception details" : "Hide exception details",
    "View exception details" : "View exception details",
    "Raw log entry" : "Raw log entry",
    "Log entry successfully copied" : "Log entry successfully copied",
    "Search log entries" : "Search log entries",
    "Caused by {exception}" : "Caused by {exception}",
    "line {line}" : "line {line}",
    "Filter log levels" : "Filter log levels",
    "Time format" : "Time format",
    "Live view" : "Live view",
    "Download / Upload logs" : "Download / Upload logs",
    "Download logs" : "بارگیری لگاریتم",
    "Show local log file" : "Show local log file",
    "Upload local log file to be displayed" : "Upload local log file to be displayed",
    "Raw data" : "Raw data",
    "Local time" : "Local time",
    "UTC time" : "UTC time",
    "Time format used for displaying the timestamp" : "Time format used for displaying the timestamp",
    "(Local log files only support the \"raw\" time format)" : "(Local log files only support the \"raw\" time format)",
    "Could not change date time format." : "Could not change date time format.",
    "Polling is disabled because server is not configured to log to file" : "Polling is disabled because server is not configured to log to file",
    "Polling (live view)" : "Polling (live view)",
    "Could not change live view setting." : "Could not change live view setting.",
    "Filter logging levels" : "Filter logging levels",
    "Could not set logging levels to show" : "Could not set logging levels to show",
    "Application" : "Application",
    "Message" : "پیام",
    "Log entry actions" : "Log entry actions",
    "Loading older log entries" : "Loading older log entries",
    "No older log entries available" : "No older log entries available",
    "Collapse row" : "Collapse row",
    "Expand row" : "Expand row",
    "Show details" : "Show details",
    "Debug" : "اشکال زدایی",
    "Info" : "اطلاعات",
    "Warning" : "هشدار",
    "Error" : "خطا",
    "Fatal" : "مهلک",
    "Could not fetch new log entries (server unavailable)" : "Could not fetch new log entries (server unavailable)",
    "Could not fetch new entries" : "Could not fetch new entries",
    "Could not copy to clipboard, please copy manually:" : "Could not copy to clipboard, please copy manually:",
    "\tfrom {address} by {user} at {time}\n" : "\tfrom {address} by {user} at {time}\n",
    "Error parsing log" : "خطا در ثبت گزارش",
    "Caused by " : "ناشی از",
    "Copy" : "کپی کردن",
    "Copy raw" : "کپی کردن خام",
    "Copy formatted" : "قالب کپی کنید",
    "No server logs" : "هیچ سرور ثبت نمی شود",
    "One or more entries are hidden by the log level filter" : "یک یا چند مدخل توسط فیلتر سطح ورود پنهان است",
    "Everything is working fine" : "همه چیز خوب است",
    "Load log file" : "فایل لاگ را بارگیری کنید.",
    "Invalid log file" : "فایل لاگ نامعتبر است.",
    "Log levels" : "سطح ورود به سیستم",
    "Log content" : "محتوا را وارد کنید",
    "Live update" : "به روز رسانی زنده"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-26.0.11.tgz: nextcloud/apps/logreader/l10n/fa.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "ورود به سیستم",
    "Log Reader" : "ورود به سیستم خواننده",
    "A log reader for Nextcloud" : "خواننده گزارش برای Nextcloud",
    "Log reader for Nextcloud" : "خواننده را برای Nextcloud وارد کنید",
    "Log reader" : "Log reader",
    "Open log reader settings" : "Open log reader settings",
    "Log reader settings" : "Log reader settings",
    "Currently the log file {file} is shown" : "Currently the log file {file} is shown",
    "Show server log" : "Show server log",
    "Live view is disabled" : "Live view is disabled",
    "No log file" : "No log file",
    "File-based logging must be enabled to access logs from the Web UI." : "File-based logging must be enabled to access logs from the Web UI.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual.",
    "Level" : "ترک",
    "App" : "برنامه",
    "No app in context" : "No app in context",
    "Time" : "زمان",
    "Copy raw entry" : "Copy raw entry",
    "Copy formatted entry" : "Copy formatted entry",
    "Hide exception details" : "Hide exception details",
    "View exception details" : "View exception details",
    "Raw log entry" : "Raw log entry",
    "Log entry successfully copied" : "Log entry successfully copied",
    "Search log entries" : "Search log entries",
    "Caused by {exception}" : "Caused by {exception}",
    "Line {line}" : "Line {line}",
    "Filter log levels" : "Filter log levels",
    "Time format" : "Time format",
    "Live view" : "Live view",
    "Download logs" : "بارگیری لگاریتم",
    "Show local log file" : "Show local log file",
    "Upload local log file to be displayed" : "Upload local log file to be displayed",
    "Raw data" : "Raw data",
    "Local time" : "Local time",
    "UTC time" : "UTC time",
    "Time format used for displaying the timestamp" : "Time format used for displaying the timestamp",
    "(Local log files only support the \"raw\" time format)" : "(Local log files only support the \"raw\" time format)",
    "Could not change date time format." : "Could not change date time format.",
    "Polling is disabled because server is not configured to log to file" : "Polling is disabled because server is not configured to log to file",
    "Polling (live view)" : "Polling (live view)",
    "Could not change live view setting." : "Could not change live view setting.",
    "Filter logging levels" : "Filter logging levels",
    "Could not set logging levels to show" : "Could not set logging levels to show",
    "Application" : "Application",
    "Message" : "پیام",
    "Log entry actions" : "Log entry actions",
    "Loading older log entries" : "Loading older log entries",
    "No older log entries available" : "No older log entries available",
    "Collapse row" : "Collapse row",
    "Expand row" : "Expand row",
    "Show details" : "Show details",
    "Debug" : "اشکال زدایی",
    "Info" : "اطلاعات",
    "Warning" : "هشدار",
    "Error" : "خطا",
    "Fatal" : "مهلک",
    "Could not fetch new log entries (server unavailable)" : "Could not fetch new log entries (server unavailable)",
    "Could not fetch new entries" : "Could not fetch new entries",
    "Could not copy to clipboard, please copy manually:" : "Could not copy to clipboard, please copy manually:",
    "\tfrom {address} by {user} at {time}\n" : "\tfrom {address} by {user} at {time}\n",
    "Error parsing log" : "خطا در ثبت گزارش",
    "Caused by " : "ناشی از",
    "Copy" : "کپی کردن",
    "Copy raw" : "کپی کردن خام",
    "Copy formatted" : "قالب کپی کنید",
    "No server logs" : "هیچ سرور ثبت نمی شود",
    "One or more entries are hidden by the log level filter" : "یک یا چند مدخل توسط فیلتر سطح ورود پنهان است",
    "Everything is working fine" : "همه چیز خوب است",
    "Load log file" : "فایل لاگ را بارگیری کنید.",
    "Invalid log file" : "فایل لاگ نامعتبر است.",
    "Log levels" : "سطح ورود به سیستم",
    "Log content" : "محتوا را وارد کنید",
    "Live update" : "به روز رسانی زنده",
    "line {line}" : "line {line}",
    "Download / Upload logs" : "Download / Upload logs"
},
"nplurals=2; plural=(n > 1);");
